AxEvent

Struct AxEvent 

pub struct AxEvent<'a, B> {
    pub opcode: B,
    pub po: usize,
    pub intra_instruction_order: usize,
    pub thread_id: ThreadId,
    pub name: String,
    pub base: &'a Event<B>,
    pub is_ifetch: bool,
}
An AxEvent (axiomatic event) is an event combined with metadata about where and when it was executed in a candidate execution. This can be combined with the footprint analysis to determine various dependency orders on events.

Fields

opcode: B

The opcode for the instruction that contained the underlying event

po: usize

The place of the event in po-order for it’s thread

intra_instruction_order: usize

If a single instruction contains multiple events, this will order them

thread_id: ThreadId

The thread id for the event

name: String

A generated unique name for the event

base: &'a Event<B>

The underlying event in the SMT trace

is_ifetch: bool

Is the event an instruction fetch (i.e. base is ReadMem with an ifetch read_kind)

Implementations

Source

impl<'a, B: BV> AxEvent<'a, B>

pub fn address(&self) -> Option<&'a Val<B>>

pub fn read_value(&self) -> Option<(&'a Val<B>, u32)>

pub fn write_data(&self) -> Option<(&'a Val<B>, u32)>