pub struct GraphEvent { /* private fields */ }Implementations
Sourceimpl GraphEvent
impl GraphEvent
Sourcepub fn from_axiomatic<'a, B: BV>(
ev: &'a AxEvent<'_, B>,
objdump: &str,
rw_values: &mut HashMap<String, String>,
) -> Self
pub fn from_axiomatic<'a, B: BV>( ev: &'a AxEvent<'_, B>, objdump: &str, rw_values: &mut HashMap<String, String>, ) -> Self
Create an event to display in a user-visible graph from an underlying axiomatic event. For display, we use the objdump output to find the human-readable assembly instruction, and get values read/written by memory events as an event name -> read/write description map.