VirtualAddress

Struct VirtualAddress 

pub struct VirtualAddress { /* private fields */ }
A concrete ARMv8 virtual address

Implementations

Source

impl VirtualAddress

pub fn from_u64(bits: u64) -> Self

Create a virtual address from a 64-bit unsigned integer. This function will clear all bits from 48 and above to guarantee it is a valid ARMv8 virtual address.

pub fn level_index(self, level: u64) -> usize

va.level_index(n) will return the index used for the translation table at level n when translating va. Panics if n > 3.

pub fn page_offset(self) -> u64

Return the offset of a virtual address within a 4K page.

pub fn from_indices( level0: usize, level1: usize, level2: usize, level3: usize, page_offset: usize, ) -> Self

Create a virtual address that will be translated by the translation table indices in order from level 0 to 3 plus a page offset. Panics if any level argument is not less than 512, and the page offset is not less than 4096.